# Syslog Manager

Syslog Manager is a terminal-based tool for manipulating and querying syslog files. It allows you to export syslog data to different formats, perform simple and complex queries, split syslog files by day and more.

## Features

1. **Export Syslog**
   - Export syslog data to a JSON file.
   - Export syslog data to a CSV file.
   - Export syslog data to a SQL file.

2. **Query Syslog**
   - Retrieve log messages between two timestamps.
   - Retrieve log messages originating from a specific process.
   - Retrieve log messages that contain specific terms.
   - **New in v2.0.0:** Support for querying data from JSON and CSV files in addition to syslog (.log) files.

3. **Split Syslog**
   - Split a syslog file into multiple files, each storing events for a single day.

4. **Count Events per Process**
   - Count the number of events generated by each process.

5. **New in v2.1.0: Hourly Report**
   - Generate a bar chart of event frequency per hour directly in the terminal. This feature helps visualize peak activity times throughout the day.

## Installation

### Prerequisites

- Python 3.12

### From PyPi (Recommended)
You can install Syslog Manager directly from PyPI using pip:

   ```bash
   pip install syslog_manager
   ```

### From GitHub Release
Alternatively, you can download the .whl package from the GitHub Releases page and install it using pip:

   ```bash
   pip install path/to/syslog_manager-x.x.x-py3-none-any.whl
   ```
Replace path/to/ with the actual path to the downloaded .whl file.

## Usage

Once installed, the syslog_manager command is available in your terminal. Below are some examples of how to use it.

### Export Syslog

1. **Export to JSON:**

   ```bash
   syslog_manager export json /path/to/syslog.log /path/to/output.json
   ```

2. **Export to CSV:**

   ```bash
   syslog_manager export csv /path/to/syslog.log /path/to/output.csv
   ```
   
3. **Export to SQL:**

   ```bash
   syslog_manager export sql /path/to/syslog.log /path/to/output.sql
   ```
   
### Query Syslog
In version 2.0.0, the query command now accepts log, JSON, and CSV files as input. The format is specified as part of the command.
1. **Retrieve Log Messages Between Two Timestamps:**

   ```bash
   syslog_manager query [log, json, csv] /path/to/syslog.[log, json, csv] between 01/01/2024 07/07/2024
   ```
   
2. **Retrieve Log Messages from a Specific Process:**

   ```bash
   syslog_manager query [log, json, csv] /path/to/syslog.[log, json, csv] from_process process_name
   ```
   
3. **Retrieve Log Messages Containing Specific Terms:**

   ```bash
   syslog_manager query [log, json, csv] /path/to/syslog.[log, json, csv] contains_words word1,word2,word3
   ```
   
### Split Syslog

1. **Split Syslog into Daily Files:**

   ```bash
   syslog_manager split /path/to/syslog.log
   ```

### Count Events per Process

1. **Count the Number of Events per Process:**

   ```bash
   syslog_manager count_event_per_process /path/to/syslog.log
   ```
   
### Hourly Report (New in v2.1.0)
1. **Generate Hourly Event Frequency Report:**

   ```bash
   syslog_manager hourly_report /path/to/syslog.log
   ```
   
This command generates an ASCII bar chart showing event frequency per hour, helping you visualize peak log activity times.

<img src="imgs/report.png" alt="Hourly Report" width="800"/>

